@@ -154,17 +154,9 @@ def run(config):
         if not dry_run:
           os.mkdir(slap_configuration_directory, 0711)
 
-      slap_key_repository = os.path.normpath('/'.join([mount_dir_path,
-                                              config.slapos_configuration,
-                                              'pki']))
-      if not os.path.exists(slap_key_repository):
-        print "Creating directory: %s" % slap_key_repository
-        if not dry_run:
-          os.mkdir(slap_key_repository, 0711)
-      certificate_repository_path = os.path.join(config.slapos_configuration,
-          'pki')
-      key_file = os.path.join(certificate_repository_path, 'computer.key')
-      cert_file = os.path.join(certificate_repository_path, 'computer.crt')
+      certificate_repository_path = os.path.join('/opt/slapos/pki')
+      key_file = os.path.join(config.slapos_configuration, 'computer.key')
+      cert_file = os.path.join(config.slapos_configuration, 'computer.crt')
       key_file_dest = os.path.normpath('/'.join([mount_dir_path,
                                               key_file]))
       cert_file_dest = os.path.normpath('/'.join([mount_dir_path,
@@ -182,10 +174,12 @@ def run(config):
       if not dry_run:
         open(slap_configuration_file, 'w').write(
           pkg_resources.resource_stream(__name__,
-            'templates/slapos.cfg.in').read() % dict(
+            'template/slapos.cfg.in').read() % dict(
               computer_id=config.computer_id, master_url=config.master_url,
               key_file=key_file, cert_file=cert_file,
-              certificate_repository_path=certificate_repository_path
+              certificate_repository_path=certificate_repository_path,
+              buildout=os.path.join('/opt', 'slapos', 'bin',
+                'buildout_networkache')
             ))
 
       hostname_path = os.path.normpath('/'.join([mount_dir_path,
@@ -201,7 +195,7 @@ def run(config):
       if not dry_run:
         open(host_path, 'w').write(
           pkg_resources.resource_stream(__name__,
-            'templates/hosts.in').read() % dict(
+            'template/hosts.in').read() % dict(
               computer_id=config.computer_id))
 
       # Creating safe sshd_config
@@ -211,7 +205,7 @@ def run(config):
       if not dry_run:
         open(sshd_path, 'w').write(
           pkg_resources.resource_stream(__name__,
-            'templates/sshd_config.in').read())
+            'template/sshd_config.in').read())
         os.chmod(sshd_path, 0600)
 
       # Creating default bridge config
@@ -221,7 +215,7 @@ def run(config):
       if not dry_run:
         open(br0_path, 'w').write(
           pkg_resources.resource_stream(__name__,
-            'templates/ifcfg-br0.in').read())
+            'template/ifcfg-br0.in').read())
 
       # Writing ssh key
 
@@ -266,7 +260,7 @@ def run(config):
         print "Creating %r" % path
         if not dry_run:
           open(path, 'w').write(pkg_resources.resource_stream(__name__,
-            'scripts/%s' % script).read())
+            'script/%s' % script).read())
           os.chmod(path, 0755)
     finally:
       _call(['umount', mount_dir_path], dry_run=dry_run)
